@@ -52,7 +52,7 @@ template<typename Operation> struct binary_traits;
  *  \code
  *  struct sine : public thrust::unary_function<float,float>
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    float operator()(float x) { return sinf(x); }
  *  };
  *  \endcode
@@ -92,7 +92,7 @@ struct unary_function
  *  \code
  *  struct exponentiate : public thrust::binary_function<float,float,float>
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    float operator()(float x, float y) { return powf(x,y); }
  *  };
  *  \endcode
@@ -138,16 +138,16 @@ struct binary_function
  *  \{
  */
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-
 #define THRUST_UNARY_FUNCTOR_VOID_SPECIALIZATION(func, impl)                   \
   template <>                                                                  \
   struct func<void>                                                            \
   {                                                                            \
+    /*! This functor is transparent. */                                        \
     using is_transparent = void;                                               \
-    __thrust_exec_check_disable__                                              \
+    /*! Function call operator. */                                             \
+    THRUST_EXEC_CHECK_DISABLE                                              \
     template <typename T>                                                      \
-    __host__ __device__                                                        \
+    THRUST_HOST_DEVICE                                                        \
     constexpr auto operator()(T&& x) const                                     \
       noexcept(noexcept(impl)) THRUST_TRAILING_RETURN(decltype(impl))          \
     {                                                                          \
@@ -159,10 +159,12 @@ struct binary_function
   template <>                                                                  \
   struct func<void>                                                            \
   {                                                                            \
+    /*! This functor is transparent. */                                        \
     using is_transparent = void;                                               \
-    __thrust_exec_check_disable__                                              \
+    /*! Function call operator. */                                             \
+    THRUST_EXEC_CHECK_DISABLE                                              \
     template <typename T1, typename T2>                                        \
-    __host__ __device__                                                        \
+    THRUST_HOST_DEVICE                                                        \
     constexpr auto operator()(T1&& t1, T2&& t2) const                          \
       noexcept(noexcept(impl)) THRUST_TRAILING_RETURN(decltype(impl))          \
     {                                                                          \
@@ -174,8 +176,6 @@ struct binary_function
   THRUST_BINARY_FUNCTOR_VOID_SPECIALIZATION(                                   \
     func, THRUST_FWD(t1) op THRUST_FWD(t2))
 
-#endif // DOXYGEN_SHOULD_SKIP_THIS
-
 
 /*! \p plus is a function object. Specifically, it is an Adaptable Binary Function.
  *  If \c f is an object of class <tt>plus<T></tt>, and \c x and \c y are objects
@@ -230,8 +230,8 @@ struct plus
 
   /*! Function call operator. The return value is <tt>lhs + rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs + rhs;
@@ -295,8 +295,8 @@ struct minus
 
   /*! Function call operator. The return value is <tt>lhs - rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs - rhs;
@@ -360,8 +360,8 @@ struct multiplies
 
   /*! Function call operator. The return value is <tt>lhs * rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs * rhs;
@@ -425,8 +425,8 @@ struct divides
 
   /*! Function call operator. The return value is <tt>lhs / rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs / rhs;
@@ -490,8 +490,8 @@ struct modulus
 
   /*! Function call operator. The return value is <tt>lhs % rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs % rhs;
@@ -547,8 +547,8 @@ struct negate
 
   /*! Function call operator. The return value is <tt>-x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &x) const
   {
     return -x;
@@ -603,8 +603,8 @@ struct square
 
   /*! Function call operator. The return value is <tt>x*x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &x) const
   {
     return x*x;
@@ -654,8 +654,8 @@ struct equal_to
 
   /*! Function call operator. The return value is <tt>lhs == rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs == rhs;
@@ -697,8 +697,8 @@ struct not_equal_to
 
   /*! Function call operator. The return value is <tt>lhs != rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs != rhs;
@@ -740,8 +740,8 @@ struct greater
 
   /*! Function call operator. The return value is <tt>lhs > rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs > rhs;
@@ -783,8 +783,8 @@ struct less
 
   /*! Function call operator. The return value is <tt>lhs < rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs < rhs;
@@ -826,8 +826,8 @@ struct greater_equal
 
   /*! Function call operator. The return value is <tt>lhs >= rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs >= rhs;
@@ -869,8 +869,8 @@ struct less_equal
 
   /*! Function call operator. The return value is <tt>lhs <= rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs <= rhs;
@@ -921,8 +921,8 @@ struct logical_and
 
   /*! Function call operator. The return value is <tt>lhs && rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs && rhs;
@@ -964,8 +964,8 @@ struct logical_or
 
   /*! Function call operator. The return value is <tt>lhs || rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs || rhs;
@@ -1021,8 +1021,8 @@ struct logical_not
 
   /*! Function call operator. The return value is <tt>!x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr bool operator()(const T &x) const
   {
     return !x;
@@ -1093,8 +1093,8 @@ struct bit_and
 
   /*! Function call operator. The return value is <tt>lhs & rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs & rhs;
@@ -1157,8 +1157,8 @@ struct bit_or
 
   /*! Function call operator. The return value is <tt>lhs | rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs | rhs;
@@ -1221,8 +1221,8 @@ struct bit_xor
 
   /*! Function call operator. The return value is <tt>lhs ^ rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs ^ rhs;
@@ -1276,8 +1276,8 @@ struct identity
 
   /*! Function call operator. The return value is <tt>x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr const T &operator()(const T &x) const
   {
     return x;
@@ -1332,8 +1332,8 @@ struct maximum
 
   /*! Function call operator. The return value is <tt>rhs < lhs ? lhs : rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs < rhs ? rhs : lhs;
@@ -1390,8 +1390,8 @@ struct minimum
 
   /*! Function call operator. The return value is <tt>lhs < rhs ? lhs : rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs < rhs ? lhs : rhs;
@@ -1442,7 +1442,7 @@ struct project1st
 
   /*! Function call operator. The return value is <tt>lhs</tt>.
    */
-  __host__ __device__
+  THRUST_HOST_DEVICE
   constexpr const T1 &operator()(const T1 &lhs, const T2 & /*rhs*/) const
   {
     return lhs;
@@ -1458,9 +1458,9 @@ struct project1st<void, void>
   /// converted to the required type, and uses perfect forwarding.
   using is_transparent = void;
   /// \brief Invocation operator - returns its first argument.
-  __thrust_exec_check_disable__
+  THRUST_EXEC_CHECK_DISABLE
   template <typename T1, typename T2>
-  __host__ __device__
+  THRUST_HOST_DEVICE
   constexpr auto operator()(T1&& t1, T2&&) const
     noexcept(noexcept(THRUST_FWD(t1)))
     THRUST_TRAILING_RETURN(decltype(THRUST_FWD(t1)))
@@ -1507,7 +1507,7 @@ struct project2nd
 
   /*! Function call operator. The return value is <tt>rhs</tt>.
    */
-  __host__ __device__
+  THRUST_HOST_DEVICE
   constexpr const T2 &operator()(const T1 &/*lhs*/, const T2 &rhs) const
   {
     return rhs;
@@ -1523,9 +1523,9 @@ struct project2nd<void, void>
   /// converted to the required type, and uses perfect forwarding.
   using is_transparent = void;
   /// \brief Invocation operator - returns its second argument.
-  __thrust_exec_check_disable__
+  THRUST_EXEC_CHECK_DISABLE
   template <typename T1, typename T2>
-  __host__ __device__
+  THRUST_HOST_DEVICE
   constexpr auto operator()(T1&&, T2&& t2) const
   noexcept(noexcept(THRUST_FWD(t2)))
   THRUST_TRAILING_RETURN(decltype(THRUST_FWD(t2)))
@@ -1561,13 +1561,13 @@ struct unary_negate
   /*! Constructor takes a \p Predicate object to negate.
    *  \param p The \p Predicate object to negate.
    */
-  __host__ __device__
+  THRUST_HOST_DEVICE
   explicit unary_negate(Predicate p) : pred(p){}
 
   /*! Function call operator. The return value is <tt>!pred(x)</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   bool operator()(const typename Predicate::argument_type& x) { return !pred(x); }
 
   /*! \cond
@@ -1594,7 +1594,7 @@ struct unary_negate
  *  \see not2
  */
 template<typename Predicate>
-  __host__ __device__
+  THRUST_HOST_DEVICE
   unary_negate<Predicate> not1(const Predicate &pred);
 
 /*! \p binary_negate is a function object adaptor: it is an Adaptable Binary
@@ -1605,6 +1605,7 @@ template<typename Predicate>
  *  There is rarely any reason to construct a <tt>binary_negate</tt> directly;
  *  it is almost always easier to use the helper function not2.
  *
+ *  \see https://en.cppreference.com/w/cpp/utility/functional/binary_negate
  */
 template<typename Predicate>
 struct binary_negate
@@ -1615,13 +1616,13 @@ struct binary_negate
   /*! Constructor takes a \p Predicate object to negate.
    *  \param p The \p Predicate object to negate.
    */
-  __host__ __device__
+  THRUST_HOST_DEVICE
   explicit binary_negate(Predicate p) : pred(p){}
 
   /*! Function call operator. The return value is <tt>!pred(x,y)</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  THRUST_EXEC_CHECK_DISABLE
+  THRUST_HOST_DEVICE
   bool operator()(const typename Predicate::first_argument_type& x, const typename Predicate::second_argument_type& y)
   {
       return !pred(x,y);
@@ -1651,7 +1652,7 @@ struct binary_negate
  *  \see not1
  */
 template<typename BinaryPredicate>
-  __host__ __device__
+  THRUST_HOST_DEVICE
   binary_negate<BinaryPredicate> not2(const BinaryPredicate &pred);
 
 /*! \}
