@@ -73,7 +73,7 @@ THRUST_NAMESPACE_BEGIN
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -95,7 +95,7 @@ THRUST_NAMESPACE_BEGIN
 template<typename DerivedPolicy,
          typename ForwardIterator,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   ForwardIterator partition(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                             ForwardIterator first,
                             ForwardIterator last,
@@ -134,7 +134,7 @@ __host__ __device__
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -201,7 +201,7 @@ template<typename ForwardIterator,
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -224,7 +224,7 @@ template<typename DerivedPolicy,
          typename ForwardIterator,
          typename InputIterator,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   ForwardIterator partition(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                             ForwardIterator first,
                             ForwardIterator last,
@@ -269,7 +269,7 @@ __host__ __device__
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -337,7 +337,7 @@ template<typename ForwardIterator,
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -369,7 +369,7 @@ template<typename DerivedPolicy,
          typename OutputIterator1,
          typename OutputIterator2,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   thrust::pair<OutputIterator1,OutputIterator2>
     partition_copy(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                    InputIterator first,
@@ -414,7 +414,7 @@ __host__ __device__
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -524,7 +524,7 @@ template<typename DerivedPolicy,
          typename OutputIterator1,
          typename OutputIterator2,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   thrust::pair<OutputIterator1,OutputIterator2>
     partition_copy(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                    InputIterator1 first,
@@ -648,7 +648,7 @@ template<typename InputIterator1,
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -670,7 +670,7 @@ template<typename InputIterator1,
 template<typename DerivedPolicy,
          typename ForwardIterator,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   ForwardIterator stable_partition(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                                    ForwardIterator first,
                                    ForwardIterator last,
@@ -712,7 +712,7 @@ __host__ __device__
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -781,7 +781,7 @@ template<typename ForwardIterator,
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -804,7 +804,7 @@ template<typename DerivedPolicy,
          typename ForwardIterator,
          typename InputIterator,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   ForwardIterator stable_partition(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                                    ForwardIterator first,
                                    ForwardIterator last,
@@ -851,7 +851,7 @@ __host__ __device__
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -925,7 +925,7 @@ template<typename ForwardIterator,
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -953,7 +953,7 @@ template<typename DerivedPolicy,
          typename OutputIterator1,
          typename OutputIterator2,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   thrust::pair<OutputIterator1,OutputIterator2>
     stable_partition_copy(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                           InputIterator first,
@@ -1004,7 +1004,7 @@ __host__ __device__
  *  ...
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -1111,7 +1111,7 @@ template<typename DerivedPolicy,
          typename OutputIterator1,
          typename OutputIterator2,
          typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   thrust::pair<OutputIterator1,OutputIterator2>
     stable_partition_copy(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                           InputIterator1 first,
@@ -1237,7 +1237,7 @@ template<typename InputIterator1,
  *
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -1256,7 +1256,7 @@ template<typename InputIterator1,
  *  \see \p find_if_not
  */
 template<typename DerivedPolicy, typename ForwardIterator, typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   ForwardIterator partition_point(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                                   ForwardIterator first,
                                   ForwardIterator last,
@@ -1289,7 +1289,7 @@ __host__ __device__
  *
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -1350,7 +1350,7 @@ template<typename ForwardIterator, typename Predicate>
  *
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
@@ -1369,7 +1369,7 @@ template<typename ForwardIterator, typename Predicate>
  *  \see \p partition
  */
 template<typename DerivedPolicy, typename InputIterator, typename Predicate>
-__host__ __device__
+THRUST_HOST_DEVICE
   bool is_partitioned(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                       InputIterator first,
                       InputIterator last,
@@ -1399,7 +1399,7 @@ __host__ __device__
  *
  *  struct is_even
  *  {
- *    __host__ __device__
+ *    THRUST_HOST_DEVICE
  *    bool operator()(const int &x)
  *    {
  *      return (x % 2) == 0;
